@@ -41,9 +41,13 @@ import org.ops4j.pax.exam.options.SystemPropertyOption;
 import org.ops4j.pax.exam.options.UrlProvisionOption;
 import org.ops4j.pax.exam.options.extra.VMOption;
 import org.ops4j.pax.exam.util.PathUtils;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 
 public abstract class AbstractJettyTestSupport {
-    protected static final String JETTY_VERSION = "11.0.25";
+    protected static final String JETTY_VERSION = "12.0.10";
+
+    protected final Logger logger = LoggerFactory.getLogger(getClass());
 
     private final String workingDirectory = String.format("%s/target/paxexam/%s/%s", PathUtils.getBaseDir(), getClass().getSimpleName(), UUID.randomUUID());
 
@@ -67,45 +71,43 @@ public abstract class AbstractJettyTestSupport {
         final int httpPort = findFreePort();
 
         return options(
-            composite(
-                when(vmOption != null).useOptions(vmOption),
-                failOnUnresolvedBundles(),
-                keepCaches(),
-                localMavenRepo(),
-                CoreOptions.workingDirectory(workingDirectory()),
-                // update pax logging for SLF4J 2
-                mavenBundle().groupId("org.ops4j.pax.logging").artifactId("pax-logging-api").version("2.3.0"),
-                optionalRemoteDebug(),
-                mavenBundle().groupId("org.apache.felix").artifactId("org.apache.felix.http.servlet-api").version("6.1.0"),
-                testBundle("bundle.filename"),
-                junitBundles(),
-                awaitility(),
+                composite(
+                        when(vmOption != null).useOptions(vmOption),
+                        failOnUnresolvedBundles(),
+                        keepCaches(),
+                        localMavenRepo(),
+                        CoreOptions.workingDirectory(workingDirectory()),
+                        optionalRemoteDebug(),
+                        mavenBundle().groupId("org.apache.felix").artifactId("org.apache.felix.http.servlet-api").version("3.0.0"),
+                        testBundle("bundle.filename"),
+                        junitBundles(),
+                        awaitility(),
 
-                config(),
-                felixHttpConfig(httpPort)
-            ).add(
-                additionalOptions()
-            )
+                        config(),
+                        felixHttpConfig(httpPort)
+                ).add(
+                        additionalOptions()
+                )
         );
     }
 
     public static ModifiableCompositeOption awaitility() {
         return composite(
-            mavenBundle().groupId("org.awaitility").artifactId("awaitility").version("4.2.1"),
-            mavenBundle().groupId("org.hamcrest").artifactId("hamcrest").version("2.2")
+                mavenBundle().groupId("org.awaitility").artifactId("awaitility").version("4.2.1"),
+                mavenBundle().groupId("org.hamcrest").artifactId("hamcrest").version("2.2")
         );
     }
 
     public static ModifiableCompositeOption config() {
         return composite(
-            mavenBundle().groupId("org.apache.felix").artifactId("org.apache.felix.configadmin").version("1.9.26")
+                mavenBundle().groupId("org.apache.felix").artifactId("org.apache.felix.configadmin").version("1.9.26")
         );
     }
 
     protected Option felixHttpConfig(final int httpPort) {
         return newConfiguration("org.apache.felix.http")
-            .put("org.osgi.service.http.port", httpPort)
-            .asOption();
+                .put("org.osgi.service.http.port", httpPort)
+                .asOption();
     }
 
     protected Option[] additionalOptions() throws IOException { // NOSONAR
@@ -142,7 +144,7 @@ public abstract class AbstractJettyTestSupport {
     public static OptionalCompositeOption localMavenRepo() {
         final String localRepository = System.getProperty("maven.repo.local", ""); // PAXEXAM-543
         return when(!localRepository.isBlank()).useOptions(
-            systemProperty("org.ops4j.pax.url.mvn.localRepository").value(localRepository)
+                systemProperty("org.ops4j.pax.url.mvn.localRepository").value(localRepository)
         );
     }
 
@@ -173,12 +175,12 @@ public abstract class AbstractJettyTestSupport {
 
     public static ModifiableCompositeOption spifly() {
         return composite(
-            mavenBundle().groupId("org.apache.aries.spifly").artifactId("org.apache.aries.spifly.dynamic.bundle").version("1.3.7"),
-            mavenBundle().groupId("org.ow2.asm").artifactId("asm-analysis").version("9.7"),
-            mavenBundle().groupId("org.ow2.asm").artifactId("asm-commons").version("9.7"),
-            mavenBundle().groupId("org.ow2.asm").artifactId("asm-tree").version("9.7"),
-            mavenBundle().groupId("org.ow2.asm").artifactId("asm-util").version("9.7"),
-            mavenBundle().groupId("org.ow2.asm").artifactId("asm").version("9.7")
+                mavenBundle().groupId("org.apache.aries.spifly").artifactId("org.apache.aries.spifly.dynamic.bundle").version("1.3.7"),
+                mavenBundle().groupId("org.ow2.asm").artifactId("asm-analysis").version("9.7"),
+                mavenBundle().groupId("org.ow2.asm").artifactId("asm-commons").version("9.7"),
+                mavenBundle().groupId("org.ow2.asm").artifactId("asm-tree").version("9.7"),
+                mavenBundle().groupId("org.ow2.asm").artifactId("asm-util").version("9.7"),
+                mavenBundle().groupId("org.ow2.asm").artifactId("asm").version("9.7")
         );
     }
 }
